pub fn try_resolve_proxy(upstream: &str) -> ProxyResolutionExpand description
Check whether the daemon is alive and has a proxy for the given upstream URL.
Returns the proxy URL (http://127.0.0.1:
pub fn try_resolve_proxy(upstream: &str) -> ProxyResolutionCheck whether the daemon is alive and has a proxy for the given upstream URL.
Returns the proxy URL (http://127.0.0.1: