pub fn init_tracing(mode: LogMode, level: LevelFilter) -> WorkerGuardExpand description
Initialize the global tracing subscriber. Returns a guard that must be held for the daemon’s lifetime to ensure the non-blocking writer flushes on drop.
pub fn init_tracing(mode: LogMode, level: LevelFilter) -> WorkerGuardInitialize the global tracing subscriber. Returns a guard that must be held for the daemon’s lifetime to ensure the non-blocking writer flushes on drop.