Structs
Constants
- CURRENT_
VERSION - Version of the
cc-switchbinary that built this crate. Recorded into the daemon state at start time so a newer CLI can detect a stale running daemon.
cc-switch binary that built this crate. Recorded into the
daemon state at start time so a newer CLI can detect a stale running daemon.