install

Function install 

pub fn install(custom_dir: Option<&str>) -> Result<()>
Install the statusLine wrapper script

Reads the current statusLine command from settings.json, generates a wrapper script that prepends the current alias name, and updates settings.json to use the wrapper script.

If no statusLine is configured, it will detect the available package manager (bun or npm) and use the appropriate command.