pub fn generate_completion(shell: &str) -> Result<()>Expand description
Generate shell completion script and install it to the standard path.
For fish/zsh/bash the output is written directly to the shell’s completion directory. For other shells the script is printed to stdout.
Errors
Returns error if shell is not supported or generation fails